@@ -73,13 +73,13 @@ class DriverUpdater():
             chmod (bool)                        : If true, it will make driver binary executable. Defaults to True.
             check_driver_is_up_to_date (bool)   : If true, it will check driver version before and after upgrade. Defaults to True.
             info_messages (bool)                : If false, it will disable all info messages. Defaults to True.
-            filename (str)                      : Specific name for driver. If given, it will replace name for driver. Defaults to empty string.
+            filename (str)                      : Specific name for driver. If given, it will replace current name for driver. Defaults to empty string.
             version (str)                       : Specific version for driver. If given, it will downloads given version. Defaults to empty string.
             check_browser_is_up_to_date (bool)  : If true, it will check browser version before specific driver update or upgrade. Defaults to False.
             enable_library_update_check (bool)  : If true, it will enable checking for library update while starting. Defaults to True.
             system_name (Union[str, list[str]]) : Specific OS for driver. Defaults to empty string.
 
-            old_return (bool) : If false, it will not return old variables such as "result and message". Defaults to True.
+            old_return (bool) : If true, it will return additional variables "result" and "message" in returning Tuple.
 
         Returns:
             str
@@ -89,9 +89,11 @@ class DriverUpdater():
         """
 
         #Initialize all variables
-        driver_path = ''
+        result_run:bool = True
+        message_run:str = ''
+        old_return = bool(kwargs.get('old_return', False))
 
-        old_return = bool(kwargs.get('old_return', True))
+        driver_path = ''
 
         _info.driver_name = driver_name
 
@@ -160,26 +162,30 @@ class DriverUpdater():
                     driver_path = list_of_paths
 
         except Exception:
+            result_run:bool = False
+
             message_run = f'error: {str(traceback.format_exc())}'
             logger.error(message_run)
 
         if old_return:
-            return True, '', driver_path
-        else:
-            return driver_path
+            return result_run, message_run, driver_path
+
+        return driver_path
 
     @staticmethod
     def __check_all_input_parameteres() -> None:
         """Private function for checking all input parameters"""
 
 
-        if not Path(_info.path).exists():
-            message = f"The specified path does not exist current path is: {_info.path}"
-            raise ValueError(message)
+        if not Path(_info.path).exists() and _info.path.endswith(os.path.sep):
+            message = f"The specified path does not exist current path is: {_info.path}, trying to create this directory"
+            logger.error(message)
+            Path(_info.path).mkdir()
+            logger.info(f'Successfully created new directory at path: {_info.path}')
 
         if not Path(_info.path).is_dir():
-            message = f"The specified path is not a folder current path is: {_info.path}"
-            raise ValueError(message)
+            message = f"The specified path is not a directory current path is: {_info.path}"
+            raise NotADirectoryError(message)
 
         if isinstance(_info.driver_name,(list, str)):
 
